import QtQuick 1.0
import QtWebKit 1.0

Rectangle {
    id: contentPage
    property string contentUrl: ""
    property string webUrl: ""

    width: parent.width
    height: parent.height
    color: "white"
    x: -parent.width
    y: 0

    onXChanged: {
        if(x == 0)
            webUrl = contentUrl;
    }

    Flickable {
        id: flickable;
        anchors.left: parent.left
        width: parent.width
        height:  parent.height
        contentWidth: webView.width
        contentHeight: webView.height
        interactive: true
        clip: true

        WebView {
            id: webView
            preferredWidth: flickable.width
            preferredHeight: flickable.height
            url: contentPage.webUrl
            smooth: false
            focus: true
        }
    }

    // mouse area for activating task bar
    Item {
        id: closingItem
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        height: taskBar.height
        MouseArea {
            anchors.fill: parent
            onClicked: {
                if(taskBar.state != "show")
                    taskBar.state = "show"
                else
                    taskBar.state = "hide"
            }
        }
    }

    // task bar
    TaskBar {
        id: taskBar
        // image from: http://www.windowswiki.info/2010/03/29/metro-icon-pack-windows-phone-7-icons/
        iconPath: "Back-button.png"
        onIconPressed: {
            contentPage.state = "hide";
        }
    }

    /*
     * Content page states
     */
    states: [
        State {
            name: "fullscreen"
            PropertyChanges { target: contentPage; x:0 }
        },
        State {
            name: "hide"
            PropertyChanges { target: contentPage; x: -parent.width }
        }
    ]
    transitions: [
        Transition {
            PropertyAnimation { properties: "x"; duration: 200; easing.type: Easing.OutCirc; }
        },
        Transition {
            from: 'fullscreen'; to: 'hide'
            PropertyAnimation { properties: "x"; duration: 100; easing.type: Easing.OutCirc; }
        }
    ]
}
