import QtQuick 1.0

Rectangle {
    id: mainWindow
    width: 1366
    height: 768
    color: appBackground

    property int topBarSize: 144
    property int barSize: 120
    property int tileMargin: 12
    property int tileHeaderFontSize: 11
    property int tileDateFontSize: 10
    property int appHeaderFontSize: 36
    property string appBackground: "#262626"
    property string tileBackground: "#86bc24"
    property string textColor: "white"
    property string uiFont: "Segoe UI"

    SplashScreen {
        id: splashScreen
    }

    XmlListModel {
        id: feedModel
        source: "http://www.digia.com/en/blogs/Qt-blog/?feed=rss"
        query: "/rss/channel/item"

        XmlRole { name: "title"; query: "title/string()" }
        XmlRole { name: "pubDate"; query: "pubDate/string()" }
        XmlRole { name: "link"; query: "link/string()" }

        onStatusChanged: {
            if (status == XmlListModel.Ready) {
                splashScreen.state = "hide";
                playbanner.start();
            }
        }
    }

    // Top bar
    Rectangle {
        id: topBar
        anchors.left: leftBar.right
        anchors.top: parent.top
        opacity: 0
        height: topBarSize
        color: appBackground
        Text {
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            text: qsTr("Qt Commercial Blog")
            font.family: uiFont;
            font.pointSize: appHeaderFontSize;
            color: textColor
        }
    }

    // left bar
    Rectangle {
        id: leftBar
        anchors.left: parent.left
        anchors.top: parent.top
        opacity: 0
        width: barSize
        height: parent.height
        color: appBackground
    }

    // Grid view
    GridView {
        id: grid
        anchors.left: leftBar.right
        anchors.top: topBar.bottom
        opacity: 0
        flow: GridView.TopToBottom
        width: parent.width - leftBar.width
        height: parent.height - topBar.height - bottomBar.height
        cellHeight: parseInt(grid.height / 3)
        cellWidth: parseInt(cellHeight * 1.5)
        clip: false
        focus: true
        model: feedModel
        delegate: RssDelegate {}

        // Only show the scrollbars when the view is moving.
        states: State {
            when: grid.movingHorizontally
            PropertyChanges { target: horizontalScrollBar; opacity: 1 }
        }

        transitions: Transition {
            NumberAnimation { properties: "opacity"; duration: 400 }
        }
    }

    // bottom bar
    Rectangle {
        id: bottomBar
        anchors.top: grid.bottom
        anchors.left: leftBar.right
        opacity: 0
        width: parent.width - leftBar.width
        height: barSize
        color: appBackground
    }

    ScrollBar {
        id: horizontalScrollBar
        width: parent.width; height: 6
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        opacity: 0
        orientation: Qt.Horizontal
        position: grid.visibleArea.xPosition
        pageSize: grid.visibleArea.widthRatio
    }

    SequentialAnimation {
         id: playbanner
         running: false
         NumberAnimation { target: topBar; property: "opacity"; to: 1.0; duration: 200}
         NumberAnimation { target: leftBar; property: "opacity"; to: 1.0; duration: 200}
         NumberAnimation { target: grid; property: "opacity"; to: 1.0; duration: 200}
         NumberAnimation { target: bottomBar; property: "opacity"; to: 1.0; duration: 200}
    }

    // mouse area for activating task bar
    Item {
        id: closingItem
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        height: taskBar.height
        MouseArea {
            anchors.fill: parent
            onClicked: {
                if(taskBar.state != "show")
                    taskBar.state = "show"
                else
                    taskBar.state = "hide"
            }
        }
    }

    // task bar
    TaskBar {
        id: taskBar
        // image from: http://www.windowswiki.info/2010/03/29/metro-icon-pack-windows-phone-7-icons/
        iconPath: "Close.png"
        onIconPressed: {
            Qt.quit();
        }
    }
}

